#region Copyright Syncfusion Inc. 2001 - 2007
//
//  Copyright Syncfusion Inc. 2001 - 2007. All rights reserved.
//
//  Use of this code is subject to the terms of our license.
//  A copy of the current license can be obtained at any time by e-mailing
//  licensing@syncfusion.com. Any infringement will be prosecuted under
//  applicable laws. 
//
#endregion

using System;
using System.Drawing;
using System.ComponentModel;
using System.Runtime.Serialization;

using Syncfusion.Windows.Forms.Diagram;

namespace Syncfusion.Windows.Forms.Diagram.Samples.DynamicSymbol
{
	/// <summary>
	/// Summary description for MySymbol.
	/// </summary>
	[Serializable()]
	public class MySymbol : Group
	{
        #region Class members
        /// <summary>
        /// Symbol rectangle part.
        /// </summary>
        private Rectangle m_outerRect = null;
		
		private TextNode m_textNode = null;
        /// <summary>
        /// Stymbol ellipse part.
        /// </summary>
        private Ellipse m_innerEllipse = null;
        /// <summary>
        /// Current symbol ellipse color.
        /// </summary>
        private int m_curEllipseColor = 0;
        /// <summary>
        /// Current symbol description.
        /// </summary>
        private string m_strDescription = "Custom Symbol";
        #endregion

        #region Class static members
        /// <summary>
        /// Default four colors for inner symbol ellipse.
        /// </summary>
        private static System.Drawing.Color[] m_ellipseColors =
        {
            Color.AliceBlue,
            Color.DeepSkyBlue,
            Color.LightBlue,
            Color.Aquamarine
        };
        #endregion

        #region Class Initialize/Finalize methods
        /// <summary>
        /// Default symbol constructor.
        /// </summary>

		public MySymbol()
        {
            //////////////////////////////////////////////////////////////////
            // Add child nodes to the symbol programmatically
            //////////////////////////////////////////////////////////////////

            // Add an outer rectangle
            this.m_outerRect = new Syncfusion.Windows.Forms.Diagram.Rectangle(0, 0, 120, 80);
            this.m_outerRect.Name = "Rectangle";
            this.m_outerRect.FillStyle.Type = Syncfusion.Windows.Forms.Diagram.FillStyleType.LinearGradient;
            this.m_outerRect.FillStyle.ForeColor = System.Drawing.Color.Orange;
            this.m_outerRect.FillStyle.Color = Color.Orange;
            this.m_outerRect.ShadowStyle.Visible = true;
			this.m_outerRect.EditStyle.AllowSelect = false;
            this.AppendChild(m_outerRect);

            // Add an inner ellipse
            this.m_innerEllipse = new Ellipse(10, 10, 100, 60);
            this.m_innerEllipse.Name = "Ellipse";
            this.m_innerEllipse.FillStyle.Color = m_ellipseColors[this.m_curEllipseColor];
			this.m_innerEllipse.EditStyle.AllowSelect = false;
			this.AppendChild(m_innerEllipse);

			this.m_textNode = new TextNode("Hello World");
			this.m_textNode.PinPoint = new PointF(60, 40);
			this.m_textNode.EditStyle.AllowSelect = false;
			this.AppendChild(m_textNode);
        }
		/// <summary>
		/// Default symbol constructor.
		/// </summary>
		public MySymbol( MySymbol src )
			: base( src )
		{
			// update reference
			m_outerRect = ( Rectangle )this.GetChild(0);
			m_innerEllipse = ( Ellipse )this.GetChild(1);
			m_textNode = ( TextNode )this.GetChild(2);
		}
        /// <summary>
        /// Serialization constructor for symbols.
        /// </summary>
        /// <param name="info">Serialization state information</param>
        /// <param name="context">Streaming context information</param>
        protected MySymbol(SerializationInfo info, StreamingContext context) : base(info, context)
        {
            this.m_strDescription = info.GetString("strDescription");
        }
        #endregion

        #region Class Public Methods
        /// <summary>
        /// This property provides an example of adding a member variable to a custom symbol
        /// and demonstrates how to handle serialization for this property.
        /// </summary>
        [
        Browsable(true),
        Category("General"),
        Description("Description of the symbol"),
        DesignerSerializationVisibility(DesignerSerializationVisibility.Visible)
        ]
        public string Description
        {
            get
            {
                return this.m_strDescription;
            }
            set
            {
                this.m_strDescription = value;
            }
        }

        #endregion

        #region Class overrides
		/// <summary>
		/// Highlight over mouse symbol.
		/// </summary>
		/// <param name="evtArgs"></param>
		protected override void OnMouseEnter()
		{
			this.m_outerRect.FillStyle.Color = Color.OrangeRed;

			base.OnMouseEnter ();
		}
        /// <summary>
        /// Reset highligtht symbol.
        /// </summary>
        /// <param name="evtArgs"></param>
		protected override void OnMouseLeave()
		{
			this.m_outerRect.FillStyle.Color = Color.DarkOrange;

			base.OnMouseLeave ();
		}
        /// <summary>
        /// Changing inner symbol ellipse color on mouse click.
        /// </summary>
        /// <param name="evtArgs"></param>
        protected override void OnMouseClick()
        {
            if (this.m_curEllipseColor == m_ellipseColors.Length-1)
            {
                this.m_curEllipseColor = 0;
            }
            else
            {
                this.m_curEllipseColor++;
            }
            this.m_innerEllipse.FillStyle.Color = m_ellipseColors[this.m_curEllipseColor];
        }
        /// <summary>
        /// Populates a SerializationInfo with the data needed to
        /// serialize the target object.
        /// </summary>
        /// <param name="info">SerializationInfo object to populate</param>
        /// <param name="context">Destination streaming context</param>
        protected override void GetObjectData(SerializationInfo info, StreamingContext context)
        {
            base.GetObjectData(info, context);

            // Additional member variables are serialized here
            info.AddValue("strDescription", this.m_strDescription);
        }
		/// <summary>
		/// Clones this instance.
		/// </summary>
		/// <returns></returns>
		public override object Clone()
		{
			return new MySymbol(this);
		}
        #endregion
    }
}
